==> haskell-dataenc-0.14.0.7-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dataenc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dataenc
version:              0.14.0.7
visibility:           public
id:                   dataenc-0.14.0.7-ii1hGFRxJ3DVALsNaDxuP
key:                  dataenc-0.14.0.7-ii1hGFRxJ3DVALsNaDxuP
license:              BSD-3-Clause
copyright:            Magnus Therning, 2007-2012, Gracjan Polak, 2014
maintainer:           Gracjan Polak <gracjanpolak@gmail.com>
author:               Magnus Therning
homepage:             http://www.haskell.org/haskellwiki/Library/Data_encoding
synopsis:             Data encoding library
description:
    Data encoding library currently providing Base16, Base32,
    Base32Hex, Base64, Base64Url, Base85, Python string escaping,
    Quoted-Printable, URL encoding, uuencode, xxencode, and yEncoding.

category:             Codec
abi:                  707c35e7ba501a2a2aa35833e9b92fb1
exposed:              True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.DataEncoding Codec.Binary.PythonString
    Codec.Binary.QuotedPrintable Codec.Binary.Url Codec.Binary.Uu
    Codec.Binary.Xx Codec.Binary.Yenc

hidden-modules:       Codec.Binary.Util
import-dirs:          /usr/lib/ghc-8.8.3/site-local/dataenc-0.14.0.7
library-dirs:         /usr/lib/ghc-8.8.3/site-local/dataenc-0.14.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/dataenc-0.14.0.7
hs-libraries:         HSdataenc-0.14.0.7-ii1hGFRxJ3DVALsNaDxuP
depends:              array-0.5.4.0 base-4.13.0.0 containers-0.6.2.1
haddock-interfaces:   /usr/share/doc/haskell-dataenc/html/dataenc.haddock
haddock-html:         /usr/share/doc/haskell-dataenc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dataenc-0.14.0.7-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dataenc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dataenc
version:              0.14.0.7
visibility:           public
id:                   dataenc-0.14.0.7-D1dPSKOniZl3x0sKqo4fkV
key:                  dataenc-0.14.0.7-D1dPSKOniZl3x0sKqo4fkV
license:              BSD-3-Clause
copyright:            Magnus Therning, 2007-2012, Gracjan Polak, 2014
maintainer:           Gracjan Polak <gracjanpolak@gmail.com>
author:               Magnus Therning
homepage:             http://www.haskell.org/haskellwiki/Library/Data_encoding
synopsis:             Data encoding library
description:
    Data encoding library currently providing Base16, Base32,
    Base32Hex, Base64, Base64Url, Base85, Python string escaping,
    Quoted-Printable, URL encoding, uuencode, xxencode, and yEncoding.

category:             Codec
abi:                  17101541d22ef5c9a2c870b7355e91b2
exposed:              True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.DataEncoding Codec.Binary.PythonString
    Codec.Binary.QuotedPrintable Codec.Binary.Url Codec.Binary.Uu
    Codec.Binary.Xx Codec.Binary.Yenc

hidden-modules:       Codec.Binary.Util
import-dirs:          /usr/lib/ghc-8.10.1/site-local/dataenc-0.14.0.7
library-dirs:         /usr/lib/ghc-8.10.1/site-local/dataenc-0.14.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/dataenc-0.14.0.7
hs-libraries:         HSdataenc-0.14.0.7-D1dPSKOniZl3x0sKqo4fkV
depends:              array-0.5.4.0 base-4.14.0.0 containers-0.6.2.1
haddock-interfaces:   /usr/share/doc/haskell-dataenc/html/dataenc.haddock
haddock-html:         /usr/share/doc/haskell-dataenc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
